==> qtjambi-networkauth-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiNetworkAuth/QAbstractOAuth_shell.h <==
#ifndef QABSTRACTOAUTH_SHELL_H
#define QABSTRACTOAUTH_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNetworkAuth/qabstractoauth.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <QtJambi/RegistryAPI>


class QAbstractOAuth_shell : public QAbstractOAuth, public QtJambiShellInterface
{
public:
    ~QAbstractOAuth_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QNetworkReply* deleteResource(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QNetworkReply* get(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void grant() override;
    QNetworkReply* head(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* post(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* put(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void resourceOwnerAuthorization(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractOAuth_access : public QAbstractOAuth
{
    jstring __qt_callback(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    static jobject __qt_generateRandomString_quint8(JNIEnv *__jni_env, jbyte length0);
    void __qt_setStatus_QAbstractOAuth_Status(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint status0);
    jobject __qt_deleteResource_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_get_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    void __qt_grant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_head_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_post_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_put_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    void __qt_resourceOwnerAuthorization_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
};

#endif // QABSTRACTOAUTH_SHELL_H

==> qtjambi-networkauth-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiNetworkAuth/QAbstractOAuth_shell.h <==
#ifndef QABSTRACTOAUTH_SHELL_H
#define QABSTRACTOAUTH_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtNetworkAuth/qabstractoauth.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtNetwork/qnetworkaccessmanager.h>
#include <QtNetwork/qnetworkreply.h>
#include <QtNetwork/qnetworkrequest.h>
#include <QtNetworkAuth/qabstractoauthreplyhandler.h>
#include <QtJambi/RegistryAPI>


class QAbstractOAuth_shell : public QAbstractOAuth, public QtJambiShellInterface
{
public:
    ~QAbstractOAuth_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    QNetworkReply* deleteResource(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QNetworkReply* get(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void grant() override;
    QNetworkReply* head(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* post(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    QNetworkReply* put(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void resourceOwnerAuthorization(const QUrl& url0, const QMap<QString, QVariant>& parameters1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractOAuth_access : public QAbstractOAuth
{
    jstring __qt_callback_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    static jobject __qt_generateRandomString_quint8(JNIEnv *__jni_env, jbyte length0);
    void __qt_setStatus_QAbstractOAuth_Status(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint status0);
    jobject __qt_deleteResource_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_get_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    void __qt_grant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_head_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_post_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    jobject __qt_put_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
    void __qt_resourceOwnerAuthorization_cref_QUrl_cref_QMap(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID url0, jobject parameters1);
};

#endif // QABSTRACTOAUTH_SHELL_H
